Crate linearmap

Crate linearmap 

👎Deprecated:

(Unused crate name)

See crate linear-map and crate indexmap for related data structures.

This crate name was reserved a bit too hastily, and it is unused. You can request ownership of this crate name if you need it.